import { Body, JsonController, Post } from 'routing-controllers';
import { OpenAPI, ResponseSchema } from 'routing-controllers-openapi';
import { IllegalJWTError, InvalidCredentialsError, JwtNotProvidedError, PasswordNeededError, RefreshTokenCountInvalidError, UsernameOrEmailNeededError } from '../errors/AuthError';
import { UserNotFoundError } from '../errors/UserErrors';
import { CreateAuth } from '../models/actions/CreateAuth';
import { HandleLogout } from '../models/actions/HandleLogout';
import { RefreshAuth } from '../models/actions/RefreshAuth';
import { Auth } from '../models/responses/Auth';
import { Logout } from '../models/responses/Logout';

@JsonController('/auth')
export class AuthController {
	constructor() {
	}

	@Post("/login")
	@ResponseSchema(Auth)
	@ResponseSchema(InvalidCredentialsError)
	@ResponseSchema(UserNotFoundError)
	@ResponseSchema(UsernameOrEmailNeededError)
	@ResponseSchema(PasswordNeededError)
	@ResponseSchema(InvalidCredentialsError)
	@OpenAPI({ description: 'Create a new access token object' })
	async login(@Body({ validate: true }) createAuth: CreateAuth) {
		let auth;
		try {
			auth = await createAuth.toAuth();
			console.log(auth);
		} catch (error) {
			return error;
		}
		return auth
	}

	@Post("/logout")
	@ResponseSchema(Logout)
	@ResponseSchema(InvalidCredentialsError)
	@ResponseSchema(UserNotFoundError)
	@ResponseSchema(UsernameOrEmailNeededError)
	@ResponseSchema(PasswordNeededError)
	@ResponseSchema(InvalidCredentialsError)
	@OpenAPI({ description: 'Create a new access token object' })
	async logout(@Body({ validate: true }) handleLogout: HandleLogout) {
		let logout;
		try {
			logout = await handleLogout.logout()
			console.log(logout);
		} catch (error) {
			return error;
		}
		return logout
	}

	@Post("/refresh")
	@ResponseSchema(Auth)
	@ResponseSchema(JwtNotProvidedError)
	@ResponseSchema(IllegalJWTError)
	@ResponseSchema(UserNotFoundError)
	@ResponseSchema(RefreshTokenCountInvalidError)
	@OpenAPI({ description: 'refresh a access token' })
	async refresh(@Body({ validate: true }) refreshAuth: RefreshAuth) {
		let auth;
		try {
			auth = await refreshAuth.toAuth();
			console.log(auth);
		} catch (error) {
			return error;
		}
		return auth
	}
}
